==> 0.0.1.tar.gz: lib/service/authservice.dart <==
part of mzcustomerlib;

class AuthenticationService  extends AuthenticationRepository{

@override
  Future<String> getAuthenticationToken(String key,String secret) async {
    
    Map<String, dynamic> jsonMap = {"grant_type": "client_credentials"};
   
    String basicAuth =
      'Basic ' + base64Encode(utf8.encode('$key:$secret'));
   var tokenApi ='https://auth.mzapiqc.mezzofy.com/v2/token';
   
    debugPrint(tokenApi);
    try {
      String jsonString = json.encode(jsonMap);



      return await http.post(Uri.parse('$tokenApi'), body: jsonString, headers: {
        "Accept": "application/json",
        'authorization': basicAuth,
        'Content-Type': 'application/json'
      }).then((http.Response response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }
//coupon listing API by customerId
@override
  Future<dynamic> getCouponlistByStatus(
      int skip, int limit, String status,String customerId,String accessToken) async {
  
    String url= 'https://serial.mzapiqc.mezzofy.com/v2/customer/' +
          customerId +
          "?include_merchant=S&status=" +
          status +
          "&" "skip=" +
          skip.toString() +
          "&limit=" +
          limit.toString();
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }


//serial listing API by customer id and couponid

@override
  Future<dynamic> getSeriallistByCustomerIdAndCouponId(
      int skip, int limit, String customerId,String couponId,String accessToken) async {

    String url= 'https://serial.mzapiqc.mezzofy.com/v2/customer/'+customerId+'?coupon_id=\''+couponId+'\'';
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }


// serial listing API by customer id and couponid
@override
  Future<dynamic> getSerialHistorylistByCustomer(
      int skip, int limit, String customerId,String accessToken) async {

    String url= 'https://serial.mzapiqc.mezzofy.com/v2/customer/'+customerId+'?history=\'T\''+ "&skip=" +
          skip.toString() +
          "&limit=" +
          limit.toString();
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }

}

==> 0.0.2.tar.gz: lib/service/authservice.dart <==
part of mzcustomerlib;

class AuthenticationService  extends AuthenticationRepository{

@override
  Future<String> getAuthenticationToken(String key,String secret) async {
    
    Map<String, dynamic> jsonMap = {"grant_type": "client_credentials"};
   
    String basicAuth =
      'Basic ' + base64Encode(utf8.encode('$key:$secret'));
   var tokenApi ='https://auth.mzapi.mezzofy.com/v2/token';
   
    debugPrint(tokenApi);
    try {
      String jsonString = json.encode(jsonMap);



      return await http.post(Uri.parse('$tokenApi'), body: jsonString, headers: {
        "Accept": "application/json",
        'authorization': basicAuth,
        'Content-Type': 'application/json'
      }).then((http.Response response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }
//coupon listing API by customerId
@override
  Future<dynamic> getCouponlistByStatus(
      int skip, int limit, String status,String customerId,String accessToken) async {
  
    String url= 'https://serial.mzapi.mezzofy.com/v2/customer/' +
          customerId +
          "?include_merchant=S&status=" +
          status +
          "&" "skip=" +
          skip.toString() +
          "&limit=" +
          limit.toString();
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }


//serial listing API by customer id and couponid

@override
  Future<dynamic> getSeriallistByCustomerIdAndCouponId(
      int skip, int limit, String customerId,String couponId,String accessToken) async {

    String url= 'https://serial.mzapi.mezzofy.com/v2/customer/'+customerId+'?coupon_id=\''+couponId+'\'';
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }


// serial listing API by customer id and couponid
@override
  Future<dynamic> getSerialHistorylistByCustomer(
      int skip, int limit, String customerId,String accessToken) async {

    String url= 'https://serial.mzapi.mezzofy.com/v2/customer/'+customerId+'?history=\'T\''+ "&skip=" +
          skip.toString() +
          "&limit=" +
          limit.toString();
String bearer = 'Bearer ' +accessToken;
    debugPrint(url);
    try {
      return await http.get(Uri.parse(url), headers: {
        'authorization': bearer
      }).then((response) async {
        if (response.statusCode == 200) {
          debugPrint(response.body);
          return response.body;
        } else {
          throw JsonResponseStatusException(
              message: response.body);
        }
      });
    } on HttpException catch (e) {
      debugPrint('Error Exception' +
          (e.message));
      throw AuthenticationException(message: e.message);
    } on SocketException catch (e) {
      debugPrint('Error Exception' + (e.message ));
      throw AuthenticationException(message: 'Server connectivity Error !!!');
    } on JsonResponseStatusException catch (e) {
      debugPrint('Error Exception' + (e.toString()));
      throw (e);
    }on Exception catch (e) {
      debugPrint(e.toString());
      throw AuthenticationException(message: 'Unknown Error !!!');
    }
  }

}
